document.addEventListener('DOMContentLoaded', () => {
  const correctionLanguageSelect = document.getElementById('correctionLanguage') || "au";
  const saveOptionsButton = document.getElementById('saveOptions');
  const statusMessageDiv = document.getElementById('statusMessage');
  const openShortcutsButton = document.getElementById('openShortcuts');

  // Load saved options
  chrome.storage.local.get(['correctionLanguageText'], (data) => {
    if (data.correctionLanguageText) {
      // Find the option with matching text
      const options = correctionLanguageSelect.options;
      for (let i = 0; i < options.length; i++) {
        if (options[i].textContent === data.correctionLanguageText) {
          correctionLanguageSelect.selectedIndex = i;
          break;
        }
      }
    } else {
      correctionLanguageSelect.value = 'en'; // Default value
    }
  });

  // Save options
  saveOptionsButton.addEventListener('click', () => {
    const selectedOption = correctionLanguageSelect.options[correctionLanguageSelect.selectedIndex];
    const correctionLanguageValue = selectedOption.value;
    const correctionLanguageText = selectedOption.textContent;

    // Save both if needed, but we'll focus on the text
    chrome.storage.local.set({ 
      correctionLanguage: correctionLanguageValue, // keep the value if needed elsewhere
      correctionLanguageText: correctionLanguageText // save the displayed text
    }, () => {
      statusMessageDiv.textContent = 'Options saved.';
      setTimeout(() => {
        statusMessageDiv.textContent = '';
      }, 1500);
    });
  });

  // Open Chrome Shortcuts page
  openShortcutsButton.addEventListener('click', () => {
    chrome.tabs.create({ url: 'chrome://extensions/shortcuts' });
  });
});
